from urllib.parse import quote
from xml.dom import minidom
from xml.etree.ElementTree import Element, SubElement, tostring

from django.http import HttpResponse

from pount.apps.api.libs.metadata import Metadata
from pount.apps.api.models.item import Item


def datacite_xml(item: Item):
    """
    Generate XML from Item's datacite metadata
    @see: https://doranum.fr/wp-content/uploads/datacite_metadata_generator_4.0.html  # noqa: E501
    @param item: instance of pount.apps.api.models.item.Item
    @return: XML string
    """

    metadata = get_data(item.metadata)

    top = Element(
        "resource",
        attrib={
            "xmlns": "http://datacite.org/schema/kernel-4",
            "xmlns:xsi": "http://www.w3.org/2001/XMLSchema-instance",
            "xsi:schemaLocation": "http://datacite.org/schema/kernel-4 http://schema.datacite.org/meta/kernel-4/metadata.xsd",  # noqa: E501
        },
    )
    title_undefined = SubElement(top, "undefined")
    title_element = SubElement(title_undefined, "title")
    title_element.text = metadata.get("title", "")
    creator_undefined = SubElement(top, "undefined")
    for creator in metadata.get("creator", []):
        creator_element = SubElement(creator_undefined, "creator")
        creator_name_element = SubElement(creator_element, "creatorName")
        creator_name_element.text = creator
    publisher_element = SubElement(top, "publisher")
    publisher_element.text = metadata.get("publisher", "")
    publication_year_element = SubElement(top, "publicationYear")
    publication_year_element.text = str(metadata.get("publicationYear", ""))
    resource_type_element = SubElement(
        top,
        "undefined",
        attrib={"resourceTypeGeneral": metadata.get("resourceTypeGeneral", "")},
    )
    resource_type_element.text = metadata.get("resourceType")

    xml = minidom.parseString(tostring(top, "utf-8")).toprettyxml()
    return xml


def get_data(metadata: list) -> dict:
    md = Metadata(metadata)
    data = {
        "creator": md.creator.value,
        "title": md.title.value,
        "publisher": md.publisher.value,
        "publicationYear": md.publicationYear.value,
        "resourceType": md.resourceType.value,
        "resourceTypeGeneral": md.resourceTypeGeneral.value,
    }
    return data


def add_content_disposition_header_for_attachment(filename, response: HttpResponse) -> HttpResponse:
    try:
        filename.encode("ascii")
        file_expr = f'filename="{filename}"'
    except UnicodeEncodeError:
        # copied from django.http.response.FileResponse
        file_expr = f"filename*=utf-8''{quote(filename)}"

    response["Content-Disposition"] = f"attachment; {file_expr}"

    return response
