from smtplib import SMTPException

from django.contrib.auth import get_user_model
from django.utils.translation import gettext_lazy as _

from pount.apps.api.libs.email import send_email
from pount.apps.api.libs.notifications import notify_group_membership
from pount.apps.api.models import Group, Permission, Role, Set

User = get_user_model()


def add_set_to_group(group: Group, set: Set):
    Permission.objects.create(
        group=group,
        role=Role.objects.get_contributor(),
        content_object=set,
    )


def remove_user_from_group(group: Group, user: User, removed_by: User) -> str:
    email_result: str = "no"

    if group.name == Group.MEMBERS:
        # Removing a user from the Members group, removes him from the project
        for _group in group.project.groups.all():
            _group.users.remove(user)

        if user.email:
            try:
                send_email(
                    _("You have left project %(project)s") % {"project": group.project.name},
                    template="email/group/removed_from_project",
                    context={"group": group},
                    recipients=user.email,
                )
                email_result = "sent"
            except (SMTPException, ConnectionError):
                email_result = "error"
    else:
        group.users.remove(user)

    notify_group_membership(removed_by, user, group, "group_user_remove")

    return email_result
