from __future__ import annotations

from nh3 import nh3

ALLOWED_TAGS: set[str] = {
    "a",
    "abbr",
    "acronym",
    "b",
    "blockquote",
    "br",
    "code",
    "div",
    "em",
    "font",
    "h1",
    "h2",
    "h3",
    "h4",
    "h5",
    "h6",
    "hr",
    "i",
    "img",
    "li",
    "ol",
    "p",
    "strike",
    "strong",
    "ul",
}

ALLOWED_ATTRS: dict[str, set] = {
    "a": {"href", "title"},
    "abbr": {"title"},
    "acronym": {"title"},
    "div": {"align"},
    "font": {"size"},
    "img": {"src", "alt", "title"},
    "p": {"align"},
}

ALLOWED_URL_SCHEMES: set[str] = {
    "http",
    "https",
    "mailto",
}


def sanitize(input: str | None = None) -> str:
    if not input:
        return ""

    cleaned = nh3.clean(
        html=input,
        tags=ALLOWED_TAGS,
        attributes=ALLOWED_ATTRS,
        strip_comments=True,
        link_rel="noopener noreferrer nofollow",
        url_schemes=ALLOWED_URL_SCHEMES,
    )

    return cleaned
