import csv

from django.http import HttpResponse
from django.utils.html import strip_tags

from pount.apps.api.libs.metadata import Metadata
from pount.apps.api.models import Item, Project, Set


def get_item_data(ids) -> tuple[list[str], list[dict]]:
    def get_metadata_value(metadata, name):
        md = Metadata(metadata)
        try:
            return getattr(md, name).value
        except AttributeError:
            return ""

    fieldnames = [
        "id",
        "title",
        "description",
        "creator",
        "publication_date",
        "resourceType",
        "resourceTypeGeneral",
    ]
    items = Item.objects.filter(id__in=ids)
    results = [
        {
            "id": str(_i.id),
            "title": _i.title,
            "description": strip_tags(_i.description or ""),
            "creator": _i.creator,
            "publication_date": (_i.publication_date.strftime("%Y-%m-%d") if _i.publication_date else ""),
            "resourceType": get_metadata_value(_i.metadata, "resourceType"),
            "resourceTypeGeneral": get_metadata_value(_i.metadata, "resourceTypeGeneral"),
        }
        for _i in items
    ]
    return fieldnames, results


def get_set_data(ids) -> tuple[list[str], list[dict]]:
    fieldnames = [
        "id",
        "title",
        "creator",
        "publication_date",
        "description",
        "items",
    ]
    sets = Set.objects.filter(id__in=ids)
    results = [
        {
            "id": str(_i.id),
            "title": _i.title,
            "creator": _i.creator,
            "publication_date": (_i.publication_date.strftime("%Y-%m-%d") if _i.publication_date else ""),
            "description": strip_tags(_i.description or ""),
            "items": _i.items.count(),
        }
        for _i in sets
    ]
    return fieldnames, results


def get_project_data(ids) -> tuple[list[str], list[dict]]:
    fieldnames = ["id", "name", "managers", "description", "sets", "items"]
    projects = Project.objects.filter(id__in=ids)
    results = [
        {
            "id": str(_i.id),
            "name": _i.name,
            "managers": ", ".join([_.name for _ in _i.managers]),
            "description": strip_tags(_i.description or ""),
            "sets": _i.sets.count(),
            "items": Item.objects.filter(set__project=_i).count(),
        }
        for _i in projects
    ]
    return fieldnames, results


def export_search_results(output: HttpResponse, fieldnames: list[str], results: list[dict]):
    writer = csv.DictWriter(output, dialect="excel", fieldnames=fieldnames)
    writer.writeheader()
    for row in results:
        writer.writerow(row)
    return output
