from dataclasses import asdict, dataclass
from string import Template

import requests
from django.conf import settings


@dataclass
class Structure:
    id: int
    nature: str
    nature_type: str = ""
    label: str = ""
    acronym: str = ""
    long_name: str = ""
    middle_name: str = ""
    short_name: str = ""
    category: str = ""

    def to_dict(self) -> dict:
        d = asdict(self)
        # In Cortex, data the was in short_name now is in middle_name
        d["short_name"] = d["short_name"] or d["middle_name"]
        # del d["nature"]
        return d

    @property
    def is_research_unit(self) -> bool:
        return self.nature == "UR"


class __StructureRef:
    headers = {
        "content-type": "application/json; charset=UTF-8",
        "Authorization": f"token {settings.CAMELOT['TOKEN']}",
    }
    url_template = Template(f"{settings.CAMELOT['URL']}warehouse/structures/code=$code")

    def get(self, structure_code) -> Structure:
        response = requests.get(
            self.url_template.substitute(code=structure_code),
            headers=self.headers,
        )
        if response.ok:
            structure_data = response.json()
            return Structure(
                id=structure_data["id"],
                label=structure_data["code"],
                **structure_data.get("datas")[0],
            )
        else:
            raise ValueError(f"Structure {structure_code} not found")


structure_reference = __StructureRef()
