import logging
from datetime import timedelta

from django.contrib.auth import get_user_model
from django.core.management import BaseCommand
from django.utils import timezone

from pount.apps.api.models import AuthenticationProvider

User = get_user_model()

logger = logging.getLogger("cron")


class Command(BaseCommand):
    help = "Delete external users not involved in projects and inactive for more than one year"  # noqa: E501

    def handle(self, *args, **options):
        internal_prefix = AuthenticationProvider.CAS.value + "/"
        one_year_ago = timezone.now() - timedelta(days=365)

        inactive_users = User.objects.filter(
            is_active=False,
            last_login__lt=one_year_ago,
        ).exclude(username__startswith=internal_prefix)

        for user in inactive_users:
            if user.is_external:
                user.delete()
                logger.info(f"External inactive user <{user.username}> deleted")
