from django.core.exceptions import ValidationError
from django.core.management import BaseCommand, CommandError
from django.utils.translation import gettext_lazy as _

from pount.apps.api.libs.item import process_metadata
from pount.apps.api.models import Item


class Command(BaseCommand):
    def add_arguments(self, parser):
        parser.add_argument("-i", "--item_id", type=str, help=_("ID of the item to process"))

    def handle(self, *args, **options):
        if options.get("item_id", None):
            try:
                items = Item.objects.filter(pk=options.get("item_id"))
                self._process_items(items)
            except Item.DoesNotExist:
                raise CommandError(_("Item not found"))
            except ValidationError as err:
                raise CommandError(str(err))
        else:
            if input(_("Are you sure that you wan to process the metadata for all items")).lower() == "yes":
                items = Item.objects.all()
                self._process_items(items)
            else:
                self.stdout.write(self.style.WARNING(_("Operation cancelled")))

    def _process_items(self, items):
        for item in items:
            self.stdout.write(f" - processing {item.id}")
            item.metadata = process_metadata(item.metadata, item.set.template)
            try:
                item.save(update_fields=["metadata"])
            except Exception:
                continue
