# Generated by Django 3.2.18 on 2023-05-30 12:08

from django.db import migrations


def copy_option_id_to_value(field: dict, option_value_id_map):
    options = field.get("options", None)
    field_name = field.get("name", "")
    if options:
        option_value_id_map[field_name] = {}
        for option in options:
            option_id = option.get('id')
            option_value_id_map[field_name].update({option.get('value'): option_id})
            option.update({"value": option_id})

    children = field.get('fields', [])
    for child in children:
        copy_option_id_to_value(child, option_value_id_map)


def options_value_from_id(template):
    option_value_id_map = {}
    for field in template.fields:
        copy_option_id_to_value(field, option_value_id_map)
    return option_value_id_map


def set_option_value_as_id(apps, schema_editor):
    Template = apps.get_model("api", "Template")
    Item = apps.get_model("api", "Item")
    for t in Template.objects.all():
        option_value_id_map = options_value_from_id(t)
        if t.scope == 4:
            for item in Item.objects.filter(set__template_id=t.id):
                for data in item.metadata:
                    for key in ["multiple", "repeatable", "is_option"]:
                        if not data.get(key, True):
                            del data[key]
                    data_value = data["value"]
                    if data_value is not None:
                        field_name = data.get("name")
                        if field_name in option_value_id_map:
                            new_value = None
                            if isinstance(data_value, dict) and (value := data_value.get("value")):
                                new_value = option_value_id_map[field_name][value]
                            if isinstance(data_value, str) and data_value:
                                new_value = option_value_id_map[field_name][data_value] if data_value else None
                            elif isinstance(data_value, list):
                                if len(data_value):
                                    if isinstance(data_value[0], str):
                                        new_value = [
                                            option_value_id_map[field_name][value]
                                            for value in data_value
                                        ]
                                    elif isinstance(data_value[0], dict):
                                        new_value = [
                                            option_value_id_map[field_name][value.get("value")]
                                            for value in data_value
                                        ]
                            data.update({
                                "value": new_value
                            })
                item.save(update_fields=["metadata"])
        t.save(update_fields=["fields"])


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0039_remove_referential_data_fields'),
    ]

    operations = [
        migrations.RunPython(
            code=set_option_value_as_id,
        )
    ]
