# Generated by Django 3.2.19 on 2023-06-14 08:37

from django.db import migrations


def rename_node_key(node: dict, from_key_name: str, to_key_name: str):
    if from_key_name in node.keys():
        node[to_key_name] = node.pop(from_key_name)
    return node


def rename_keys(ref_data, old_name: str, new_name: str):
    if isinstance(ref_data.definition, dict):
        nodes = ref_data.definition.get("nodes", {})
        for node_id in nodes.keys():
            ref_data.definition["nodes"][node_id] = rename_node_key(nodes[node_id], from_key_name=old_name,
                                                                    to_key_name=new_name)

    if isinstance(ref_data.lists, dict):
        for lang in ref_data.lists.keys():
            nodes = ref_data.lists.get(lang, {}).get("nodes", {})
            for node_id in nodes.keys():
                ref_data.lists[lang]["nodes"][node_id] = [
                    rename_node_key(_node, from_key_name=old_name, to_key_name=new_name) for _node in
                    nodes[node_id]]

    ref_data.save(update_fields=["definition", "lists"])


def rename_parents_to_ancestors(apps, schema_editor):
    ReferentialData = apps.get_model("api", "ReferentialData")

    for ref_data in ReferentialData.objects.all():
        rename_keys(ref_data, old_name="parents", new_name="ancestors")


def rename_ancestors_to_parents(apps, schema_editor):
    ReferentialData = apps.get_model("api", "ReferentialData")

    for ref_data in ReferentialData.objects.all():
        rename_keys(ref_data, old_name="ancestors", new_name="parents")


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0042_auto_20230609_0956'),
    ]

    operations = [
        migrations.RunPython(
            code=rename_ancestors_to_parents,
            reverse_code=rename_parents_to_ancestors,
        )
    ]
