from django.contrib.auth import get_user_model
from django.db import models
from django.db.models import JSONField

from pount.apps.api.models.project import Project

User = get_user_model()


class GroupManager(models.Manager):
    def create_for_project(self, name: str, description: str, project: Project):
        group = Group.objects.create(
            name=name,
            description=description,
            project=project,
            settings={},
        )
        return group


class Group(models.Model):
    MEMBERS = "Members"
    MANAGERS = "Managers"

    name = models.CharField(max_length=255, blank=False)
    description = models.TextField(blank=True, null=True)
    project = models.ForeignKey(
        Project,
        related_name="groups",
        on_delete=models.CASCADE,
    )
    users = models.ManyToManyField(User, related_name="project_groups")
    settings = JSONField()

    objects = GroupManager()

    class Meta:
        constraints = [models.UniqueConstraint(fields=["name", "project"], name="unique_group_name")]

    def __str__(self):
        return self.name

    @property
    def is_default_group(self) -> bool:
        return self.name in [self.MEMBERS, self.MANAGERS]

    def delete(self, **kwargs):
        if self.is_default_group:
            raise ValueError("Default group cannot be deleted")
        return super().delete(**kwargs)
