import json
import uuid

from pount.apps.api.models.permission import Role
from pount.apps.api.models.template import Template
from pount.apps.api.rules import (
    GROUP_EDIT,
    PROJECT_CREATE,
    PROJECT_DELETE,
    PROJECT_EDIT,
    PROJECT_VIEW,
    SET_CREATE,
    SET_DELETE,
    SET_EDIT,
    SET_REQUEST_DELETE,
    SET_VIEW,
)

DATACITE_FIELDS = json.loads(
    '[{"id": "6qgq1netsxh", "hint": "Les principaux chercheurs impliqués dans la production des données, ou les auteurs de la publication, par ordre de priorité.", "name": "creator", "type": "text", "exist": true, "label": "Creator", "visible": true, "parentId": "root", "required": true, "component": "UsfText", "parent_id": "root", "protected": true, "max_repeat": 10, "repeatable": true, "default_repeat": 0}, {"id": "5vxode5mjsh", "hint": "A name or title by which a resource is known.", "name": "title", "type": "text", "exist": true, "label": "Title", "visible": true, "parentId": "root", "required": true, "component": "UsfText", "parent_id": "root", "protected": true}, {"id": "unym14mu68", "hint": "The name of the entitythat holds, archives, publishes prints, distributes, releases, issues, or produces the resource. This property will be used to formulate the citation, so consider the prominence of the role.", "name": "publisher", "type": "text", "exist": true, "label": "Publisher", "visible": true, "parentId": "root", "required": true, "component": "UsfText", "parent_id": "root", "protected": true}, {"id": "m1w8jje0wsh", "max": "", "min": "", "hint": "The year when the data was or will be made publicly available", "name": "publicationYear", "type": "number", "exist": true, "label": "PublicationYear", "visible": true, "parentId": "root", "required": true, "component": "UsfText", "parent_id": "root", "protected": true, "placeholder": "YYYY"}, {"id": "t3mz0p5bfv", "exist": true, "fields": [{"id": "6mcq0o9y04f", "width": "6", "fields": [{"id": "yxuullxsicj", "hint": "The format is open, but the preferred format is a single term of some detail so that a pair can be formed with the sub-property.", "name": "resourceType", "type": "text", "exist": true, "label": "ResourceType", "visible": true, "parentId": "6mcq0o9y04f", "required": true, "component": "UsfText", "parent_id": "6mcq0o9y04f", "protected": true, "placeholder": "A description of the resource."}], "visible": true, "parentId": "t3mz0p5bfv", "component": "UsfCol", "parent_id": "t3mz0p5bfv"}, {"id": "g8mrg14u4ji", "width": "6", "fields": [{"id": "2qwhbanmbsc", "hint": "The general type of a resource.", "name": "resourceTypeGeneral", "exist": true, "label": "resourceTypeGeneral", "options": [{"id": "zl8ouisyt1q", "label": "Audiovisual", "owner": "2qwhbanmbsc", "value": "zl8ouisyt1q"}, {"id": "6n2eecqvnsd", "label": "Collection", "owner": "2qwhbanmbsc", "value": "6n2eecqvnsd"}, {"id": "uj938jmk2rl", "label": "DataPaper", "owner": "2qwhbanmbsc", "value": "uj938jmk2rl"}, {"id": "eais7vwztb9", "label": "Dataset", "owner": "2qwhbanmbsc", "value": "eais7vwztb9"}, {"id": "q2duprhhsob", "label": "Event", "owner": "2qwhbanmbsc", "value": "q2duprhhsob"}, {"id": "qrg4713tgvr", "label": "Image", "owner": "2qwhbanmbsc", "value": "qrg4713tgvr"}, {"id": "a2pero9dchm", "label": "InteractiveResource", "owner": "2qwhbanmbsc", "value": "a2pero9dchm"}, {"id": "2596bsai2tu", "label": "Model", "owner": "2qwhbanmbsc", "value": "2596bsai2tu"}, {"id": "u0cz9bvinwl", "label": "PhysicalObject", "owner": "2qwhbanmbsc", "value": "u0cz9bvinwl"}, {"id": "rkmvtr3wosq", "label": "Service", "owner": "2qwhbanmbsc", "value": "rkmvtr3wosq"}, {"id": "4wi5c7baejl", "label": "Software", "owner": "2qwhbanmbsc", "value": "4wi5c7baejl"}, {"id": "tsheh0mmsc", "label": "Sound", "owner": "2qwhbanmbsc", "value": "tsheh0mmsc"}, {"id": "e6esmnvs0rj", "label": "Text", "owner": "2qwhbanmbsc", "value": "e6esmnvs0rj"}, {"id": "lqg41cmnwf", "label": "Workflow", "owner": "2qwhbanmbsc", "value": "lqg41cmnwf"}, {"id": "gtz6mcevk2", "label": "Other", "owner": "2qwhbanmbsc", "value": "gtz6mcevk2"}], "visible": true, "multiple": false, "parentId": "g8mrg14u4ji", "required": true, "component": "UsfSelect", "parent_id": "g8mrg14u4ji", "protected": true}], "visible": true, "parentId": "t3mz0p5bfv", "component": "UsfCol", "parent_id": "t3mz0p5bfv"}], "visible": true, "parentId": "root", "vertical": false, "component": "UsfRow", "parent_id": "root", "protected": true}]'  # noqa
)
DATACITE_MESSAGES = json.loads(
    '{"default": "fr", "locales": {"en": {"rtl": false, "2qwhbanmbsc": {"hint": "General type of the resource to choose from the drop-down list.", "label": "Resource Type General"}, "5vxode5mjsh": {"hint": "A name or title by which a resource is known.", "label": "Title"}, "6qgq1netsxh": {"hint": "The main researchers involved in producing the data, or the authors of the publication, in priority order", "label": "Creator"}, "m1w8jje0wsh": {"hint": "The year when the data was or will be made publicly available", "label": "PublicationYear"}, "yxuullxsicj": {"hint": "The format is open, but the preferred format is a single term of some detail so that a pair can be formed with the sub-property.Example dataset/census data where dataset is the general resource type and census data is the resource type.", "label": "RessourceType"}, "unym14mu68": {"hint": "The name of the entity that holds, archives, publishes prints, distributes, releases, issues, or produces the resource. This property will be used to formulate the citation, so consider the prominence of the role.", "label": "Publisher"}}, "fr": {"2qwhbanmbsc": {"hint": "Type général de la ressource à choisir dans la liste déroulante.", "label": "Type de ressource  général"}, "5vxode5mjsh": {"hint": "Un nom ou un titre par lequel une ressource est connue.", "label": "Titre"}, "6qgq1netsxh": {"hint": "Les principaux chercheurs impliqués dans la production des données, ou les auteurs de la publication, par ordre de priorité.", "label": "Créateur"}, "m1w8jje0wsh": {"hint": "L\'année où les données ont été ou seront mises à la disposition du public", "label": "Année de publication"}, "yxuullxsicj": {"hint": "Réponse libre de préférence un terme qui précise le type de ressource . Exemple  dataset/census data  où dataset est le type de ressource général et census data le type de ressource", "label": "Type de ressource"}, "unym14mu68": {"hint": "Le nom de l\'entité qui détient, archive, publie, imprime, distribue, diffuse, émet ou produit la ressource. Cette propriété sera utilisée pour formuler la citation, il faut donc tenir compte de l\'importance du rôle.", "label": "Editeur"}, "e6esmnvs0rj": {"label": "Texte"}}}}'  # noqa
)


def initialize_roles():
    access_rights = {
        PROJECT_CREATE: True,
        PROJECT_EDIT: True,
        PROJECT_VIEW: True,
        PROJECT_DELETE: False,
        GROUP_EDIT: True,
        SET_CREATE: True,
        SET_EDIT: True,
        SET_VIEW: True,
        SET_DELETE: False,
        SET_REQUEST_DELETE: True,
    }
    try:
        r = Role.objects.get_manager()
        r.access_rights = access_rights
        r.save()
    except Role.DoesNotExist:
        Role.objects.create(
            name=Role.MANAGER,
            access_rights=access_rights,
        )

    access_rights = {
        PROJECT_CREATE: False,
        PROJECT_EDIT: False,
        PROJECT_VIEW: True,
        PROJECT_DELETE: False,
        GROUP_EDIT: False,
        SET_CREATE: False,
        SET_EDIT: True,
        SET_VIEW: True,
        SET_DELETE: False,
        SET_REQUEST_DELETE: False,
    }
    try:
        r = Role.objects.get_contributor()
        r.access_rights = access_rights
        r.save()
    except Role.DoesNotExist:
        Role.objects.create(
            name=Role.CONTRIBUTOR,
            access_rights=access_rights,
        )

    access_rights = {
        PROJECT_CREATE: False,
        PROJECT_EDIT: False,
        PROJECT_VIEW: True,
        PROJECT_DELETE: False,
        GROUP_EDIT: False,
        SET_CREATE: False,
        SET_EDIT: False,
        SET_VIEW: True,
        SET_DELETE: False,
        SET_REQUEST_DELETE: False,
    }
    try:
        r = Role.objects.get_member()
        r.access_rights = access_rights
        r.save()
    except Role.DoesNotExist:
        Role.objects.create(
            name=Role.MEMBER,
            access_rights=access_rights,
        )


def initialize_templates():
    if not Template.objects.filter(name="datacite").exists():
        Template.objects.create(
            id=uuid.UUID("3e9db7dc-99ca-4034-a6f1-08a5691a3bb2"),
            name="datacite",
            fields=DATACITE_FIELDS,
            messages=DATACITE_MESSAGES,
            scope=Template.SCOPE_BASE,
        )
