from datetime import timedelta

from django.conf import settings
from django.db import models
from django.utils import timezone

from pount.apps.api.models.fields import UUIDAutoField
from pount.apps.api.models.user import AuthenticationProvider


class Ticket(models.Model):
    id = UUIDAutoField()
    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE)
    provider = models.CharField(
        max_length=25,
        null=False,
        choices=[(_.name, _.value) for _ in AuthenticationProvider],
    )
    expires_at = models.DateTimeField()

    def save(self, *args, **kwargs):
        if self.expires_at is None:
            self.expires_at = timezone.now() + timedelta(seconds=60)
        return super().save(*args, **kwargs)

    @property
    def is_expired(self) -> bool:
        return self.expires_at < timezone.now()
