from django.db import models
from django.db.models import JSONField
from notifications.base.models import AbstractNotification

from pount.apps.api.models.project import Project
from pount.apps.api.models.set import Set


class Notification(AbstractNotification):
    project = models.ForeignKey(Project, on_delete=models.CASCADE, null=True)
    set = models.ForeignKey(Set, on_delete=models.CASCADE, null=True)
    data = JSONField(blank=True, null=True)

    class Meta(AbstractNotification.Meta):
        abstract = False
        app_label = "api"

    def __str__(self):
        """
        Customize AbstractNotification.__str__() to allow i18n
        """
        ctx = {
            "actor": self.actor,
            "verb": self.verb,
            "action_object": self.action_object,
            "target": self.target,
            "timesince": self.timesince(),
        }
        if self.target:
            if self.action_object:
                return "%(actor)s %(verb)s %(action_object)s on %(target)s %(timesince)s ago" % ctx  # noqa:E501
            return "%(actor)s %(verb)s %(target)s %(timesince)s ago" % ctx
        if self.action_object:
            return "%(actor)s %(verb)s %(action_object)s %(timesince)s ago" % ctx
        return "%(actor)s %(verb)s %(timesince)s ago" % ctx
