from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.db import models
from django.db.models import JSONField

from pount.apps.api.models.group import Group


class RoleQuerySet(models.QuerySet):
    def get_manager(self):
        return self.get(name=Role.MANAGER)

    def get_contributor(self):
        return self.get(name=Role.CONTRIBUTOR)

    def get_member(self):
        return self.get(name=Role.MEMBER)


class Role(models.Model):
    MANAGER = "Manager"
    CONTRIBUTOR = "Contributor"
    MEMBER = "Member"

    name = models.CharField(max_length=64, unique=True)
    access_rights = JSONField()
    # +perms, see .permission.Permission

    objects = RoleQuerySet.as_manager()

    class Meta:
        ordering = ["id"]

    def __str__(self):
        return self.name


class Permission(models.Model):
    group = models.ForeignKey(Group, related_name="perms", null=False, on_delete=models.CASCADE)
    role = models.ForeignKey(Role, related_name="perms", null=False, on_delete=models.PROTECT)
    content_type = models.ForeignKey(
        ContentType,
        on_delete=models.CASCADE,
        # related_name permissions would collide with django.contrib.auth.permissions  # noqa:E501
        related_name="perms",
    )
    object_id = models.UUIDField()
    content_object = GenericForeignKey("content_type", "object_id")

    class Meta:
        constraints = [
            models.UniqueConstraint(
                fields=["group", "role", "content_type", "object_id"],
                name="unique_role_for_group",
            )
        ]
