from collections import OrderedDict

from rest_framework import pagination
from rest_framework.response import Response


class StandardPagination(pagination.PageNumberPagination):
    page_size_query_param = "page_size"
    max_page_size = 1000

    def get_paginated_response(self, data):
        return Response(
            OrderedDict(
                [
                    ("count", self.page.paginator.count),
                    ("next_page", self.page.next_page_number() if self.page.has_next() else None),
                    ("previous_page", self.page.previous_page_number() if self.page.has_previous() else None),
                    ("results", data),
                ]
            )
        )

    def get_page_size(self, request):
        """
        query_param page_size with value 0 represents a
        page_size of max_page_size
        """
        if self.page_size_query_param and self.max_page_size:
            try:
                if request.query_params[self.page_size_query_param] == "0":
                    return self.max_page_size
            except (KeyError, ValueError):
                pass
        return super().get_page_size(request)

    def get_paginated_response_schema(self, schema):
        response_schema = super().get_paginated_response_schema(schema)
        response_schema["properties"] |= {
            "next": {
                "type": "integer",
                "nullable": True,
                "example": 2,
            },
            "previous": {
                "type": "integer",
                "nullable": True,
                "example": None,
            },
        }
        return response_schema


class NotificationPagination(StandardPagination):
    page_size = 5
