import rules

from pount.apps.api.rules import predicates

PROJECT_CREATE = "api.add_project"
PROJECT_VIEW = "api.view_project"
PROJECT_EDIT = "api.change_project"
PROJECT_DELETE = "api.delete_project"
PROJECT_LIST_TEMPLATES = "api.list_templates_project"
PROJECT_REQUEST_DELETE = "api.request_delete_project"
GROUP_EDIT = "api.change_group"
SET_CREATE = "api.add_set"
SET_VIEW = "api.view_set"
SET_EDIT = "api.change_set"
SET_DELETE = "api.delete_set"
SET_REQUEST_DELETE = "api.request_delete_set"
ITEM_CREATE = "api.add_item"
ITEM_VIEW = "api.view_item"
ITEM_EDIT = "api.change_item"
ITEM_DELETE = "api.delete_item"
ITEM_REQUEST_DELETE = "api.request_delete_item"
TEMPLATE_CREATE = "api.add_template"
TEMPLATE_VIEW = "api.view_template"
TEMPLATE_EDIT = "api.change_template"
TEMPLATE_DELETE = "api.delete_template"
TEMPLATE_ADD_TO_PROJECT = "api.add_to_project_template"
TEMPLATE_LIST_GLOBALS = "api.list_globals_template"

MANAGE_REFERENTIAL_IN_PROJECT = "api.add_referential_to_project"


rules.add_perm(PROJECT_CREATE, predicates.is_project_creator)
rules.add_perm(PROJECT_EDIT, predicates.is_authenticated & predicates.is_project_manager)
rules.add_perm(
    PROJECT_VIEW,
    predicates.is_project_public | predicates.is_project_member | predicates.is_project_manager,
)
rules.add_perm(PROJECT_DELETE, predicates.is_superadmin)
rules.add_perm(PROJECT_LIST_TEMPLATES, predicates.is_project_member)
rules.add_perm(PROJECT_REQUEST_DELETE, predicates.is_project_manager)

rules.add_perm(GROUP_EDIT, predicates.is_authenticated & predicates.is_group_manager)


rules.add_perm(SET_CREATE, predicates.is_project_manager | predicates.is_superadmin)
rules.add_perm(SET_EDIT, predicates.is_superadmin | predicates.is_set_project_manager)
rules.add_perm(SET_VIEW, predicates.is_set_public | predicates.is_set_project_member)
rules.add_perm(SET_REQUEST_DELETE, predicates.is_set_project_manager)
rules.add_perm(SET_DELETE, predicates.is_set_project_manager)

rules.add_perm(ITEM_CREATE, predicates.is_set_project_manager | predicates.is_set_contributor)
rules.add_perm(
    ITEM_VIEW,
    predicates.is_superadmin | predicates.is_item_public | predicates.is_item_project_member,
)
rules.add_perm(
    ITEM_EDIT,
    predicates.is_authenticated
    & (predicates.is_superadmin | predicates.is_item_creator | predicates.is_item_project_manager),
)
rules.add_perm(ITEM_REQUEST_DELETE, predicates.is_item_project_manager)
rules.add_perm(ITEM_DELETE, predicates.is_item_creator | predicates.is_item_project_manager)

rules.add_perm(TEMPLATE_VIEW, predicates.is_template_project_member)
rules.add_perm(
    TEMPLATE_EDIT,
    (predicates.is_template_global & predicates.is_superadmin) | predicates.is_template_project_manager,
)
rules.add_perm(
    TEMPLATE_DELETE,
    predicates.is_superadmin
    | (predicates.is_template_local & predicates.is_template_project_manager & predicates.is_template_unused),
)
rules.add_perm(TEMPLATE_LIST_GLOBALS, predicates.is_authenticated)
rules.add_perm(TEMPLATE_ADD_TO_PROJECT, predicates.is_project_manager)

rules.add_perm(
    MANAGE_REFERENTIAL_IN_PROJECT,
    predicates.is_authenticated & (predicates.is_superadmin | predicates.is_project_manager),
)
