from django.contrib.auth import get_user_model
from django.utils import timezone
from rest_framework import serializers
from rest_framework.exceptions import ValidationError
from rest_framework_simplejwt.tokens import RefreshToken

User = get_user_model()


class TokenObtainSerializer(serializers.Serializer):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    def get_token(self, user: User):
        token = RefreshToken.for_user(user)
        token["iss"] = self.context["request"].get_host()
        token["sub"] = user.username
        token["nbf"] = timezone.now().timestamp()
        return token

    def validate_user(self, attrs, user: User):
        if not user.is_active:
            raise ValidationError("User is not active")
        data = super().validate(attrs)
        refresh = self.get_token(user)
        data["refresh"] = str(refresh)
        data["access"] = str(refresh.access_token)
        return data

    def validate(self, attrs):
        return self.validate_user(attrs, self.context["user"])
