from django.utils.timesince import timesince
from django.utils.translation import gettext_lazy as _
from rest_framework import serializers

from pount.apps.api.libs.notifications import translated_verb
from pount.apps.api.models.notification import Notification


class NotificationSerializer(serializers.ModelSerializer):
    title = serializers.SerializerMethodField()
    timesince = serializers.SerializerMethodField()

    @staticmethod
    def get_title(obj: Notification) -> str:
        if obj.actor is None:
            actor_name = _("Deleted user")
        else:
            actor_name = obj.actor.name
        if obj.target:
            if obj.action_object:
                return f"{actor_name} {translated_verb(obj.verb)} ({obj.action_object} {_('on')} {obj.target})"  # noqa:E501
            return f"{actor_name} {translated_verb(obj.verb)} {obj.target}"
        if obj.action_object:
            return f"{actor_name} {translated_verb(obj.verb)} {obj.action_object}"  # noqa: E501
        return f"{actor_name} {translated_verb(obj.verb)}"

    @staticmethod
    def get_timesince(obj: Notification) -> str:
        return timesince(obj.timestamp)

    class Meta:
        model = Notification
        fields = ["id", "title", "timesince", "unread"]
