from django.contrib.auth import get_user_model
from rest_framework import serializers

from pount.apps.api.models import Template
from pount.apps.api.serializers.project import ProjectNameSerializer
from pount.apps.api.serializers.user import CreatorSerializer

User = get_user_model()


class TemplateSerializer(serializers.ModelSerializer):
    creator = CreatorSerializer(read_only=True)
    project = ProjectNameSerializer(read_only=True)
    project_id = serializers.UUIDField(write_only=True, allow_null=True)

    class Meta:
        model = Template
        fields = [
            "id",
            "name",
            "fields",
            "messages",
            "private_fields",
            "created_at",
            "updated_at",
            "scope",
            "project",
            "project_id",
            "creator",
        ]

    def create(self, validated_data):
        template = Template.objects.create(creator=self.context["request"].user, **validated_data)
        return template

    def update(self, instance, validated_data):
        if "scope" in validated_data.keys():
            # scope can not be changed
            del validated_data["scope"]
        return super().update(instance, validated_data)


class TemplateNameSerializer(TemplateSerializer):
    class Meta(TemplateSerializer.Meta):
        fields = [
            "id",
            "name",
        ]


class CompactTemplateSerializer(TemplateSerializer):
    class Meta(TemplateSerializer.Meta):
        model = Template
        fields = ["id", "name", "scope"]
