from pathlib import Path
from unittest.mock import patch

from pount.apps.api.libs.item import import_items_from_csv
from pount.apps.api.models import Item, Project, Set, User
from pount.apps.api.models.init import initialize_roles, initialize_templates
from pount.tests import TestCase


class TestImportBug(TestCase):
    fixtures = [
        Path(__file__).resolve(strict=True).parent / "fixtures/creator.json",
        Path(__file__).resolve(strict=True).parent / "fixtures/project.json",
        Path(__file__).resolve(strict=True).parent / "fixtures/template.json",
        Path(__file__).resolve(strict=True).parent / "fixtures/set.json",
    ]

    @classmethod
    def setUpClass(cls):
        with patch("pount.apps.api.models.template.handle_update_item_metadata_on_template_save"):
            initialize_roles()
            initialize_templates()
            super().setUpClass()

    def test_csv_import_with_select_option_values(self):
        manager = User.objects.get(pk="abbe5407-91a4-4e99-aede-cdd461bae581")
        project = Project.objects.get(pk="742dd373-2c61-4809-bd44-b65e71b15956")
        project.add_member(manager)
        project.add_manager(manager)
        set_model = Set.objects.get(pk="0e02edfe-bbf8-4644-a2dd-5d59f715d065")
        with open(Path(__file__).resolve(strict=True).parent / "fixtures/import.csv", "rb") as csv_file:
            number_of_items = import_items_from_csv(csv_file, set_model, manager)

        self.assertEqual(number_of_items, 5)

        imported_item = Item.objects.get(title="1929. Coelodonta antiquitatis")
        resource_type_general_md = [
            _meta for _meta in imported_item.metadata if _meta["name"] == "resourceTypeGeneral"
        ][0]
        self.assertEqual(resource_type_general_md["value"], ["gtz6mcevk2"])
