import datetime
import json

import factory
from django.conf import settings
from factory.django import DjangoModelFactory

from pount.apps.api.models import Referential
from pount.apps.api.tests.factories.project import ProjectFactory
from pount.apps.api.tests.factories.user import UserFactory


def get_definition_fixture():
    with open(settings.BASE_DIR / "apps/api/tests/fixtures/referential_definition.json") as definition_file:
        definition = json.load(definition_file)
    return definition


class ProjectReferentialFactory(DjangoModelFactory):
    class Meta:
        model = Referential

    name = factory.Faker("sentence")
    creator = factory.SubFactory(UserFactory)
    project = factory.SubFactory(ProjectFactory)
    version = datetime.datetime.now().strftime("%Y%m%d%H%I%S")
    current_version = True
    scope = Referential.Scope.SCOPE_PROJECT
    languages = {"default": "fr", "available": ["fr"], "translations": {}}
    definition = get_definition_fixture()
    lists = {}

    @classmethod
    def _create(cls, model_class, *args, **kwargs):
        manager = cls._get_manager(model_class)
        return manager.create_with_node_list(*args, **kwargs)


class PublicReferentialFactory(ProjectReferentialFactory):
    scope = Referential.Scope.SCOPE_PUBLIC


class BaseReferentialFactory(ProjectReferentialFactory):
    project = None
    scope = Referential.Scope.SCOPE_BASE
