import factory
from factory.django import DjangoModelFactory

from pount.apps.api.models import Set, Template
from pount.apps.api.models.init import DATACITE_FIELDS, DATACITE_MESSAGES
from pount.apps.api.tests.factories.project import ProjectFactory
from pount.apps.api.tests.factories.template import TemplateFactory
from pount.apps.api.tests.factories.user import UserFactory


class SetFactory(DjangoModelFactory):
    class Meta:
        model = Set

    title = "Set title"
    creator = factory.SubFactory(UserFactory)
    template = factory.SubFactory(
        TemplateFactory,
        scope=Template.SCOPE_SET,
        fields=DATACITE_FIELDS,
        messages=DATACITE_MESSAGES,
    )
    project = factory.SubFactory(ProjectFactory)


class SetForMemberFactory(SetFactory):
    @factory.post_generation
    def members(self, create, members, **kwargs):
        if not create:
            return
        if isinstance(members, list):
            for _member in members:
                self.project.add_member(_member)
        else:
            self.project.add_member(members)


class SetForManagerFactory(SetForMemberFactory):
    @factory.post_generation
    def managers(self, create, managers, **kwargs):
        if not create:
            return
        self.project.add_manager(managers)
