from unittest.mock import patch

from rest_framework.test import APITestCase

from pount.apps.api.libs.template import get_template_fieldnames
from pount.apps.api.tests.factories.template import TemplateFactory


class TemplateFieldnamesExportTest(APITestCase):
    @patch("pount.apps.api.models.template.handle_update_item_metadata_on_template_save")
    def setUp(self, update_mock) -> None:
        self.fields = [
            {
                "id": "s",
                "name": "Simple field",
                "repeatable": False,
                "multiple": False,
            },
            {
                "id": "r",
                "name": "Repeated field",
                "repeatable": True,
                "multiple": False,
            },
            {
                "id": "m",
                "name": "Multiple field",
                "repeatable": False,
                "multiple": True,
            },
            {
                "id": "rm",
                "name": "Multiple, repeated field",
                "repeatable": True,
                "multiple": True,
            },
            {
                "id": "req",
                "name": "Required field",
                "required": True,
            },
            {
                "id": "parent_id",
                "repeatable": False,
                "multiple": False,
                "fields": [
                    {
                        "id": "child",
                        "name": "Child field",
                    }
                ],
            },
        ]
        self.template = TemplateFactory(fields=self.fields)

    def test_repeated_fieldname_is_postfixed_with_asterisk(self):
        fieldnames = get_template_fieldnames(self.template)
        self.assertEqual(fieldnames["r"], "Repeated field *")

    def test_multiple_fieldname_is_postfixed_with_x(self):
        fieldnames = get_template_fieldnames(self.template)
        self.assertEqual(fieldnames["m"], "Multiple field x")

    def test_required_fieldname_is_postfixed_with_o(self):
        fieldnames = get_template_fieldnames(self.template)
        self.assertEqual(fieldnames["req"], "Required field o")

    def test_multiple_repeated_fieldname_is_postfixed_with_asterisk_and_x(
        self,
    ):
        fieldnames = get_template_fieldnames(self.template)
        self.assertEqual(fieldnames["rm"], "Multiple, repeated field *, x")

    def test_nest_field_is_present_in_fieldnames(self):
        fieldnames = get_template_fieldnames(self.template)
        self.assertEqual(fieldnames["child"], "Child field")

    def test_field_without_name_uses_id_as_name(self):
        fieldnames = get_template_fieldnames(self.template)
        self.assertEqual(
            fieldnames["parent_id"],
            "parent_id",
        )
