import uuid

from pount.apps.api.libs.template import get_referentials_used_in_template
from pount.exceptions import TemplateFieldError
from pount.tests import TestCase


class ListOfReferentialsUsedInTemplateTest(TestCase):
    def test_extract_referential_ids_from_template_fields(self):
        id1 = uuid.uuid4()
        id2 = uuid.uuid4()
        fields = [
            {"referential_id": str(id1), "component": "ReferentialComponent"},
            {"referential_id": str(uuid.uuid4()), "component": "UsfText"},
            {"referential_id": str(uuid.uuid4()), "component": "UsfRow"},
            {"referential_id": str(id2), "component": "ReferentialComponent"},
        ]
        template_ids = get_referentials_used_in_template(fields)
        self.assertListEqual(
            [id1, id2],
            template_ids,
        )

    def test_extract_referential_ids_raises_exception_if_id_is_not_a_uuid(self):
        fields = [
            {"referential_id": "not-a-uuid", "component": "ReferentialComponent"},
            {"referential_id": str(uuid.uuid4()), "component": "UsfText"},
            {"referential_id": str(uuid.uuid4()), "component": "UsfRow"},
            {"referential_id": str(uuid.uuid4()), "component": "ReferentialComponent"},
        ]
        with self.assertRaises(TemplateFieldError) as ctx:
            get_referentials_used_in_template(fields)
        self.assertIn(
            "Referential ID could not be converted to UUID",
            str(ctx.exception),
        )
