from unittest.mock import patch
from uuid import uuid4

from pount.apps.api.libs.template import update_items_using_template
from pount.apps.api.models.init import initialize_roles
from pount.apps.api.tests.factories.item import ItemFactory
from pount.apps.api.tests.factories.set import SetFactory
from pount.apps.api.tests.factories.template import TemplateFactory
from pount.tests import TestCase


class UpdateItemsUsingTemplateTest(TestCase):
    def setUp(self):
        self.patcher1 = patch("pount.apps.api.models.template.handle_update_item_metadata_on_template_save")
        self.patcher1.start()

    def tearDown(self):
        self.patcher1.stop()

    @patch("pount.apps.api.models.item.make_item_citation")
    @patch("pount.apps.api.libs.item.process_metadata")
    def test_item_is_updated_with_template_uuid(self, process_metadata, make_item_citation):
        initialize_roles()
        make_item_citation.return_value = "citation"
        template = TemplateFactory()
        set_model = SetFactory(template=template)
        item = ItemFactory(set=set_model)
        process_metadata.return_value = [{"name": "foo", "value": "bar"}]
        update_items_using_template(template=template.id)
        process_metadata.assert_called_with(item.metadata, template)
        item.refresh_from_db()
        self.assertListEqual(
            item.metadata,
            [{"name": "foo", "value": "bar"}],
        )

    @patch("pount.apps.api.models.item.make_item_citation")
    @patch("pount.apps.api.libs.item.process_metadata")
    def test_item_is_not_udpated_if_template_does_not_exist(self, process_metadata, make_item_citation):
        initialize_roles()
        update_items_using_template(template=uuid4())
        process_metadata.assert_not_called()
