from unittest import TestCase

from pount.apps.api.libs.citation import make_item_citation


class ItemCitationTest(TestCase):
    def setUp(self) -> None:
        self.metadata = [
            {
                "id": "6qgq1netsxh",
                "name": "creator",
                "value": ["Creator 1", "Creator 2", "Creator 3"],
                "multiple": False,
                "is_option": False,
                "repeatable": True,
            },
            {
                "id": "5vxode5mjsh",
                "name": "title",
                "value": "Title of the item",
                "multiple": False,
                "is_option": False,
                "repeatable": False,
            },
            {
                "id": "unym14mu68",
                "name": "publisher",
                "value": "Université de Strasbourg",
                "multiple": False,
                "is_option": False,
                "repeatable": False,
            },
            {
                "id": "m1w8jje0wsh",
                "name": "publicationYear",
                "value": "2021",
                "multiple": False,
                "is_option": False,
                "repeatable": False,
            },
        ]

    def test_complete_citation(self):
        self.assertEqual(
            make_item_citation(self.metadata),
            'Creator 1 & Creator 2 & Creator 3, "Title of the item", Université de Strasbourg, 2021',  # noqa
        )

    def test_with_one_creator(self):
        self.metadata[0]["value"] = ["Creator name"]
        self.assertEqual(
            make_item_citation(self.metadata),
            'Creator name, "Title of the item", Université de Strasbourg, 2021',  # noqa
        )

    def test_with_doi(self):
        doi = {
            "id": "b8geg8bmkef",
            "name": "DOI",
            "value": "https://doi.org/10.80425/FK2/6AKIOM",
            "multiple": False,
            "is_option": False,
            "repeatable": False,
        }
        self.metadata.append(doi)
        self.assertEqual(
            make_item_citation(self.metadata),
            'Creator 1 & Creator 2 & Creator 3, "Title of the item", Université de Strasbourg, 2021, https://doi.org/10.80425/FK2/6AKIOM',  # noqa
        )
