from django.contrib.auth import get_user_model
from django.test import TestCase
from django.utils.translation import gettext_lazy as _
from django.utils.translation import override

from pount.apps.api.libs.notifications import translated_verb
from pount.apps.api.models.notification import Notification

User = get_user_model()


class NotificationTest(TestCase):
    def setUp(self) -> None:
        user = User.objects.create_user("username")
        self.notification = Notification.objects.create(
            recipient=user,
            actor=user,
            verb="project_join",
            level=Notification.LEVELS.info,
        )

    def test_translated_verb(self):
        self.assertEqual(_(self.notification.verb), "project_join")
        with override("en"):
            self.assertEqual(translated_verb(self.notification.verb), "has joined project")
        with override("fr"):
            self.assertEqual(translated_verb(self.notification.verb), "a rejoint le projet")
