import responses
from django.conf import settings

from pount.apps.api.libs.structure import Structure, structure_reference
from pount.tests import TestCase

structure_response = {
    "id": 607,
    "code": "UMR123",
    "datas": [
        {
            "nature": "UR",
            "acronym": "ACRO",
            "long_name": "Long lab name",
            "nature_type": "UMR",
            "middle_name": "ACRO LAB",
            "category": "JUR",
        }
    ],
    "status": "OU",
}


class StructureTest(TestCase):
    headers = (
        {
            "content-type": "application/json; charset=UTF-8",
            "Authorization": f"token {settings.CAMELOT['TOKEN']}",
        },
    )

    @responses.activate
    def test_structure_ref(self):
        code = "CODE"
        responses.add(
            responses.GET,
            f"{settings.CAMELOT['URL']}warehouse/structures/code={code}",
            headers=self.headers,
            json=structure_response,
        )
        structure: Structure = structure_reference.get("CODE")
        self.assertIsInstance(structure, Structure)
        self.assertTrue(structure.is_research_unit)
        self.assertEqual(
            structure.to_dict()["short_name"],
            structure_response["datas"][0]["middle_name"],
        )

    @responses.activate
    def test_structure_not_found(self):
        code = "KO"
        responses.add(
            responses.GET,
            f"{settings.CAMELOT['URL']}warehouse/structures/code={code}",
            status=404,
            headers=self.headers,
        )
        with self.assertRaises(ValueError) as ctx:
            structure_reference.get(code)
            self.assertIn("Structure KO not found", str(ctx.exception))
