import datetime as dt
from io import StringIO

from django.contrib.auth import get_user_model
from django.core.management import call_command
from django.test import TestCase
from django.utils import timezone

User = get_user_model()


class CleanTest(TestCase):
    def setUp(self) -> None:
        self.inactive_user_1 = User.objects.create_user(
            username="inactive_user_1",
            last_login=timezone.now() - dt.timedelta(days=500),
            is_active=False,
        )
        self.inactive_user_2 = User.objects.create_user(
            username="inactive_user_2",
            last_login=timezone.now() - dt.timedelta(days=30),
            is_active=False,
        )

    def test_inactive_user_not_logged_in_recently_is_deleted(self):
        out = StringIO()
        call_command("clean_inactive_users", stdout=out)
        with self.assertRaises(User.DoesNotExist):
            self.inactive_user_1.refresh_from_db()

    def test_inactive_user_recently_logged_in_is_not_deleted(self):
        out = StringIO()
        call_command("clean_inactive_users", stdout=out)
        self.inactive_user_2.refresh_from_db()

    def test_active_user_recently_logged_in_is_not_deleted(self):
        self.inactive_user_1.is_active = True
        self.inactive_user_1.save()
        out = StringIO()
        call_command("clean_inactive_users", stdout=out)
        self.inactive_user_1.refresh_from_db()
