from unittest.mock import patch

from pount.apps.api.models import Set, Template
from pount.apps.api.models.init import initialize_roles
from pount.apps.api.models.template import DELETED_SUFFIX
from pount.apps.api.tests.factories.set import SetFactory
from pount.tests import TestCase


class SetDeleteTest(TestCase):
    @classmethod
    def setUpTestData(cls):
        initialize_roles()

    @patch("pount.apps.api.models.template.handle_update_item_metadata_on_template_save")
    def test_template_name_changed_when_set_is_soft_deleted(self, update_mock):
        suffix_length = len(DELETED_SUFFIX)
        set = SetFactory()
        set.delete()
        self.assertEqual(
            set.template.name[-suffix_length:],
            DELETED_SUFFIX,
        )

    @patch("pount.apps.api.models.template.handle_update_item_metadata_on_template_save")
    def test_template_is_deleted_when_set_is_hard_deleted(self, update_mock):
        set = SetFactory()
        template = set.template
        set.delete(hard_delete=True)
        with self.assertRaises(Set.DoesNotExist):
            set.refresh_from_db()
        with self.assertRaises(Template.DoesNotExist):
            template.refresh_from_db()
