from unittest.mock import patch

from pount.apps.api.models import Referential, Template
from pount.apps.api.tests.factories.referential import BaseReferentialFactory
from pount.apps.api.tests.factories.template import TemplateFactory
from pount.tests import TestCase


class UsedReferentialsAreUpdatedOnSave(TestCase):
    @patch("pount.apps.api.models.template.handle_update_item_metadata_on_template_save")
    def test_referentials_used_are_extracted_on_save(self, update_mock):
        referential: Referential = BaseReferentialFactory()
        fields = [
            {"referential_id": str(referential.id), "component": "ReferentialComponent"},
            {"referential_id": "", "component": "UsfText", "type": "text"},
        ]
        template: Template = TemplateFactory(fields=fields)
        template.save()
        self.assertEqual(
            1,
            template.used_referentials.count(),
        )
        self.assertEqual(
            [_ref.id for _ref in template.used_referentials.all()],
            [referential.id],
        )
