from django.test import TestCase

from pount.apps.api import rules
from pount.apps.api.models import User
from pount.apps.api.models.init import initialize_roles
from pount.apps.api.models.project import Project


class CreateProjectTest(TestCase):
    def setUp(self) -> None:
        initialize_roles()
        self.superuser = User.objects.create_superuser("superuser")
        self.creator = User.objects.create_user("creator", settings={"project_creator": True})
        self.manager = User.objects.create_user("manager")
        self.member = User.objects.create_user("member")
        self.public = User.objects.create_user("public")
        self.project = Project.objects.create(
            name="Project name",
        )
        self.project.add_member(self.member)
        self.project.add_member(self.manager)
        self.project.add_manager(self.manager)

    def test_superuser_and_creator_can_create_a_project(self):
        self.assertTrue(self.superuser.has_perm(rules.PROJECT_CREATE))
        self.assertTrue(self.creator.has_perm(rules.PROJECT_CREATE))

    def test_other_roles_cannot_create_a_project(self):
        for user in (self.manager, self.member, self.public):
            self.assertFalse(user.has_perm(rules.PROJECT_CREATE))

    def test_only_managers_can_edit_project(self):
        self.assertTrue(self.manager.has_perm(rules.PROJECT_EDIT, self.project))
        for user in (self.creator, self.member, self.public):
            self.assertFalse(user.has_perm(rules.PROJECT_EDIT, self.project))

    def test_only_superuser_can_delete_a_project(self):
        self.assertTrue(self.superuser.has_perm(rules.PROJECT_DELETE, self.project))
        for user in (self.creator, self.manager, self.member, self.public):
            self.assertFalse(user.has_perm(rules.PROJECT_DELETE, self.project))
