from unittest.mock import patch
from uuid import uuid4

from pount.apps.api.tasks import (
    handle_build_node_lists_on_referential_save,
    handle_update_item_metadata_on_referential_save,
    handle_update_item_metadata_on_template_save,
)
from pount.apps.api.tests.factories.referential import BaseReferentialFactory
from pount.tests import TestCase


class HandleBuildNodeListOnReferentialSaveTest(TestCase):
    @patch("pount.apps.api.libs.referential.clear_cache_for_referential")
    @patch("pount.apps.api.libs.referential.generate_node_lists")
    def test_handle_build_node_lists_on_referential_save(self, generate_node_lists, clear_cache_for_referential):
        referential = BaseReferentialFactory()
        handle_build_node_lists_on_referential_save(referential.id)
        generate_node_lists.assert_called_once_with(referential)
        clear_cache_for_referential.assert_called_once_with(referential)

    @patch("pount.apps.api.libs.referential.clear_cache_for_referential")
    @patch("pount.apps.api.libs.referential.generate_node_lists")
    def test_nothing_is_done_if_referential_does_not_exist(self, generate_node_lists, clear_cache_for_referential):
        handle_build_node_lists_on_referential_save(uuid4())
        generate_node_lists.assert_not_called()
        clear_cache_for_referential.assert_not_called()


class HandleUpdateMetadataOnReferentialSaveTest(TestCase):
    def test_update_items_using_referential_is_called(self):
        with patch("pount.apps.api.libs.referential.update_items_using_referential") as update_items_using_referential:
            referential_id = uuid4()
            handle_update_item_metadata_on_referential_save(referential_id=referential_id)
        update_items_using_referential.assert_called_once_with(referential_id=referential_id)


class HandleUpdateItemMetadataOnTemplateSave(TestCase):
    def test_update_items_using_template_is_called(self):
        with patch("pount.apps.api.libs.template.update_items_using_template") as update_items_using_template:
            template_id = uuid4()
            handle_update_item_metadata_on_template_save(template_id=template_id)
        update_items_using_template.assert_called_once_with(template=template_id)
