from rest_framework.authtoken.models import Token
from rest_framework.reverse import reverse

from pount.apps.api.models.init import initialize_roles
from pount.apps.api.tests.factories.project import ProjectForMemberFactory
from pount.apps.api.tests.factories.user import UserFactory
from pount.tests import APITestCase


class TokenAuthenticationTest(APITestCase):
    def test_can_create_drf_token_for_user(self):
        user = UserFactory()
        with self.assertRaises(Token.DoesNotExist):
            getattr(user, "auth_token")

        token = Token.objects.create(user=user)
        self.assertEqual(
            token,
            getattr(user, "auth_token"),
        )

    def test_drf_token_can_be_used_to_access_api(self):
        initialize_roles()

        response = self.get(
            reverse("project-list"),
            user=None,
        )
        self.response_unauthorized(response)

        user = UserFactory()
        project = ProjectForMemberFactory(members=[user], is_public=False)
        token = Token.objects.create(user=user)
        response = self.get(
            reverse("project-detail", kwargs={"pk": project.id}),
            HTTP_AUTHORIZATION=f"Token {token.key}",
        )
        self.response_ok(response)
