from unittest.mock import patch

from django.conf import settings
from django.core import mail
from django.template import TemplateDoesNotExist
from django.test import TestCase

from pount.apps.api.libs.email import send_email


class EmailTest(TestCase):
    def test_send_email_requires_existing_text_template(self):
        with self.assertRaises(TemplateDoesNotExist) as ctx:
            send_email("Email subject", "non_existing_template", {}, "user@pount.org")
        self.assertIn("non_existing_template.txt", str(ctx.exception))

    @patch("pount.apps.api.libs.email.send_mail")
    def test_send_email_loads_text_template_with_context(self, mock_send_mail):
        with patch("pount.apps.api.libs.email.loader") as mock_loader:
            mock_loader.render_to_string.return_value = "rendered_template"
            send_email(
                "Email subject",
                "template_name",
                {"key": "value"},
                "user@pount.org",
            )
            mock_loader.assert_call_count = 2
            mock_send_mail.assert_called_once()
            mock_send_mail.assert_called_with(
                "[pount] Email subject",
                "rendered_template",
                settings.POUNT_ADMIN_EMAIL,
                ["user@pount.org"],
                html_message="rendered_template",
            )

    def test_sent_email(self):
        with patch("pount.apps.api.libs.email.loader") as mock_loader:
            mock_loader.render_to_string.return_value = "rendered_template"
            send_email("Email subject", "template_name", {}, "user@pount.org")
        self.assertEqual(len(mail.outbox), 1)
        sent_mail = mail.outbox[0]
        self.assertEqual("[pount] Email subject", sent_mail.subject)
        self.assertEqual("rendered_template", sent_mail.body)
        self.assertEqual(["user@pount.org"], sent_mail.recipients())
        self.assertEqual(settings.POUNT_ADMIN_EMAIL, sent_mail.from_email)
