from django.contrib.auth import get_user_model
from django.test import TestCase

from pount.apps.api.models.group import Group
from pount.apps.api.models.init import initialize_roles
from pount.apps.api.models.project import Project

User = get_user_model()


class ProjectTest(TestCase):
    def setUp(self) -> None:
        initialize_roles()

    def test_create_default_groups_for_project(self):
        # Default Members and Managers groups are created by post_save signal
        project = Project.objects.create(
            name="New project",
        )
        groups = Group.objects.filter(project=project).all()
        self.assertEqual(len(groups), 2)
        self.assertListEqual(
            sorted([_.name for _ in groups]),
            sorted([Group.MEMBERS, Group.MANAGERS]),
        )
        self.assertListEqual(
            sorted([_.description for _ in groups]),
            sorted([Group.MEMBERS, Group.MANAGERS]),
        )

    def test_user_manager_status(self):
        project = Project.objects.create(
            name="New project",
        )
        user = User.objects.create_user("user")
        self.assertFalse(project.is_user_manager(user))
        project.add_member(user)
        project.add_manager(user)
        self.assertTrue(project.is_user_manager(user))

    def test_only_member_can_be_added_as_manager(self):
        project = Project.objects.create(
            name="New project",
        )
        user = User.objects.create_user("user")
        with self.assertRaises(ValueError) as ctx:
            project.add_manager(user)
        self.assertEqual(str(ctx.exception), "User is not a project member.")
