from django.conf import settings
from rest_framework.exceptions import ValidationError

from pount.apps.api.validators import JSONSchemaValidator
from pount.tests import TestCase


class JSONSchemaValidatorTest(TestCase):
    def setUp(self) -> None:
        self.schema_root = settings.BASE_DIR / "apps/api/tests/fixtures/"

    def test_valid_json_returns_value(self):
        with self.settings(JSON_SCHEMA_DIR=self.schema_root):
            validator = JSONSchemaValidator(schema="schema.json")
            value = {"required_key": "Some value", "optional_key": 42}
            self.assertDictEqual(validator(value), value)

    def test_validator_schema_argument_is_a_posix_path(self):
        schema = settings.BASE_DIR / "apps/api/tests/fixtures/schema.json"
        validator = JSONSchemaValidator(schema=schema)
        value = {"required_key": "Some value", "optional_key": 42}
        self.assertDictEqual(validator(value), value)

    def test_invalid_json_raises_validation_error(self):
        with self.settings(JSON_SCHEMA_DIR=self.schema_root):
            validator = JSONSchemaValidator(schema="schema.json")
            value = {"required_key": "Key value", "optional_key": "I am not a number"}
            with self.assertRaises(ValidationError) as ctx:
                validator(value)
            self.assertIn("JSON Schema validation error", str(ctx.exception))

    def test_schema_file_must_exist(self):
        with self.assertRaises(ValueError) as ctx:
            JSONSchemaValidator(schema="not-a-valid-file-path.schema.json")
        self.assertIn("Schema is not a file or is not readable", str(ctx.exception))
