from unittest.mock import patch

from django.utils.functional import SimpleLazyObject
from rest_framework.reverse import reverse

from pount.apps.api.models.init import initialize_templates
from pount.apps.api.tests.factories.user import UserFactory
from pount.tests import APITestCase


class GlobalSearchView(APITestCase):
    def setUp(self):
        self.user = UserFactory()

    def test_anonymous_access_is_not_authorized(self):
        response = self.get(
            reverse("search"),
            user=None,
        )
        self.response_unauthorized(response)

    def test_page_number_can_not_be_gt_100(self):
        response = self.get(
            f"{reverse('search')}?page=101",
            user=self.user,
        )
        self.response_bad_request(response)

    def test_params_are_passed_to_query_class(self):
        with patch("pount.apps.api.models.template.handle_update_item_metadata_on_template_save"):
            initialize_templates()

        with patch("pount.apps.api.views.search.Query") as mock_query:
            self.get(
                f"{reverse('search')}",
                {
                    "page": 3,
                    "page_size": 20,
                    "project_ids": "1,2,3",
                    "set_ids": "1,2,3",
                    "q": "search me",
                },
                HTTP_ACCEPT_LANGUAGE="fr-FR",
                user=self.user,
            )
        mock_query.assert_called_once_with(
            language="fr",
            user=SimpleLazyObject(lambda: self.user),
            page="3",
            page_size="20",
            project_ids="1,2,3",
            set_ids="1,2,3",
        )
        mock_query.return_value.execute.assert_called_with(query="search me")
