from django.contrib.auth import get_user_model
from rest_framework import status
from rest_framework.reverse import reverse
from rest_framework.test import APITestCase

from pount.apps.api.models import AuthenticationProvider
from pount.apps.api.tests.factories.user import UserFactory

User = get_user_model()


class UserTest(APITestCase):
    def setUp(self) -> None:
        self.user = User.objects.create_user("username")
        self.admin = User.objects.create_user("admin", is_staff=True)

    def test_access_to_users_api_requires_admin_privilege(self):
        response = self.client.get(
            reverse("user-list"),
        )
        self.assertEqual(response.status_code, status.HTTP_401_UNAUTHORIZED)
        self.client.force_login(self.admin)
        response = self.client.get(reverse("user-list"))
        self.assertEqual(response.status_code, status.HTTP_200_OK)


class UpdateUserTest(APITestCase):
    def setUp(self) -> None:
        self.internal_user = UserFactory(
            username="internal",
            authentication_provider=AuthenticationProvider.CAS.value,
        )
        self.external_user = UserFactory(username="external")

    def test_ask_for_info_ldap_update_sets_flag_on_user(self):
        self.client.force_login(self.internal_user)
        response = self.client.patch(reverse("user-profile-refresh"))
        self.internal_user.refresh_from_db()
        self.assertEqual(status.HTTP_200_OK, response.status_code)
        self.assertTrue(self.internal_user.settings["refresh_info"])

    def test_ask_for_info_ldap_update_fails_on_external_user(self):
        self.client.force_login(self.external_user)
        response = self.client.patch(reverse("user-profile-refresh"))
        self.assertEqual(status.HTTP_400_BAD_REQUEST, response.status_code)
        with self.assertRaises(KeyError) as ctx:
            self.external_user.settings["refresh_info"]
        self.assertEqual("'refresh_info'", str(ctx.exception))
