from django.urls import include, path
from rest_framework import routers
from rest_framework_nested import routers as nestedrouters
from rest_framework_simplejwt.views import TokenObtainPairView, TokenRefreshView

from pount.apps.api import views
from pount.apps.api.routers import BulkDeleteRouter
from pount.apps.api.views.referential import NestedReferentialViewSet
from pount.apps.api.views.search import search_export

router = routers.DefaultRouter()
bulk_delete_router = BulkDeleteRouter()


router.register(
    r"notifications/unread",
    views.notification.UnreadNotificationsViewSet,
    basename="notification",
)
router.register(r"projects", views.ProjectViewSet)
router.register(r"groups", views.GroupViewSet)
bulk_delete_router.register(r"items", views.ItemViewSet)
bulk_delete_router.register(r"sets", views.SetViewSet)
router.register(r"templates", views.TemplateViewSet)
router.register(r"referentials", views.ReferentialViewSet)
router.register(r"users", views.UserViewSet)
mediafiles_router = nestedrouters.NestedDefaultRouter(bulk_delete_router, r"items", lookup="items")
mediafiles_router.register(r"mediafiles", views.item.MediaFileViewSet)

nested_referential_router = nestedrouters.NestedSimpleRouter(router, r"projects", lookup="project")
nested_referential_router.register(r"referentials", NestedReferentialViewSet, basename="nested_referential")

urlpatterns = [
    path(
        "notifications/mark_all_read/",
        views.notification.mark_all_read,
        name="notification-mark-all-read",
    ),
    path("logout/", views.login.user_logout, name="logout"),
    path("login/cas/", views.login.login_cas, name="login-cas"),
    path("login/local/", TokenObtainPairView.as_view(), name="login-local"),
    path("login/token/", views.login.jwt_token, name="login-token"),
    path("login/refresh/", TokenRefreshView.as_view(), name="token-refresh"),
    path(
        "login/password-reset/",
        views.login.password_reset_initialize,
        name="login-password-reset-initialize",
    ),
    path(
        "login/password-reset/signin/",
        views.login.password_reset_signin,
        name="login-password-reset-signin",
    ),
    path("users/profile/", views.user.ProfileView.as_view(), name="user-profile"),
    path(
        "users/profile/email/",
        views.user.change_email,
        name="user-profile-change-email",
    ),
    path(
        "users/profile/password/",
        views.user.change_password,
        name="user-profile-change-password",
    ),
    path(
        "users/profile/ldap-refresh/",
        views.user.ask_for_ldap_info_update,
        name="user-profile-refresh",
    ),
    path(
        "users/profile/thumbnail/",
        views.user.ThumbnailView.as_view(),
        name="user-profile-thumbnail",
    ),
    path("users/invite/", views.user.invite_user, name="user-invite"),
    path(
        "users/invite/validate/",
        views.user.invite_validate,
        name="user-validate-invitation",
    ),
    path(
        "users/invite/signup/",
        views.user.signup_from_invitation,
        name="user-signup-from-invitation",
    ),
    path(
        "users/invite/internal/",
        views.user.invite_internal_user,
        name="user-invite-internal-user",
    ),
    path(
        "items/<uuid:pk>/post_url/",
        views.item.post_url,
        name="item-post-url",
    ),
    path(
        "items/<uuid:pk>/mediafiles/rti/<str:filename>",
        views.item.get_rti_file,
        name="item-get-rti",
    ),
    path("", include(router.urls)),
    path("", include(mediafiles_router.urls)),
    path("", include(bulk_delete_router.urls)),
    path("", include(nested_referential_router.urls)),
    path(
        "export/search/",
        search_export,
        name="search-export",
    ),
    path("search/", views.search.global_search, name="search"),
]
