from drf_spectacular.utils import extend_schema
from rest_framework import mixins, status, viewsets
from rest_framework.decorators import action, api_view, permission_classes
from rest_framework.generics import get_object_or_404
from rest_framework.permissions import IsAuthenticated
from rest_framework.response import Response

from pount.apps.api.models import Notification
from pount.apps.api.pagination import NotificationPagination
from pount.apps.api.serializers.notification import NotificationSerializer


class UnreadNotificationsViewSet(mixins.ListModelMixin, viewsets.GenericViewSet):
    serializer_class = NotificationSerializer
    permission_classes = [IsAuthenticated]
    pagination_class = NotificationPagination
    queryset = Notification.objects.none()

    def get_queryset(self):
        return self.request.user.notifications.unread().order_by("-timestamp")

    @action(methods=["PATCH"], detail=True)
    def mark_read(self, request, pk):
        notification = get_object_or_404(
            request.user.notifications,
            pk=pk,
        )
        notification.mark_as_read()
        return self.list(self, request)


@extend_schema(
    request=None,
    responses={
        status.HTTP_204_NO_CONTENT: None,
    },
)
@api_view(http_method_names=["PATCH"])
@permission_classes([IsAuthenticated])
def mark_all_read(request):
    request.user.notifications.unread().mark_all_as_read()
    return Response(status=status.HTTP_204_NO_CONTENT)
