import factory
from factory.django import DjangoModelFactory

from pount.apps.api import models
from pount.apps.api.models import Template


class UserFactory(DjangoModelFactory):
    class Meta:
        model = models.User

    first_name = factory.Faker("first_name")
    last_name = factory.Faker("last_name")


class TemplateFactory(DjangoModelFactory):
    class Meta:
        model = models.Template

    name = factory.Sequence(lambda n: f"Template {n}")


class ProjectFactory(DjangoModelFactory):
    class Meta:
        model = models.Project

    name = "Project name"
    is_public = True


class SetFactory(DjangoModelFactory):
    class Meta:
        model = models.Set

    title = "Set title"
    creator = factory.SubFactory(UserFactory)
    template = factory.SubFactory(TemplateFactory, scope=Template.SCOPE_SET)
    project = factory.SubFactory(ProjectFactory)
    is_public = True


class ItemFactory(DjangoModelFactory):
    class Meta:
        model = models.Item

    title = "Item title"
    is_public = True
    metadata = [
        {
            "id": "abc123def",
            "name": "title",
            "value": title,
            "repeatable": False,
            "multiple": False,
        }
    ]
    creator = factory.SubFactory(UserFactory)
    set = factory.SubFactory(SetFactory, creator=factory.SelfAttribute("..creator"))
