import datetime as dt
from unittest.mock import patch

from django.contrib.auth import get_user_model
from django.utils import timezone

from pount.apps.api.models import init
from pount.apps.api.models.item import MediaFile
from pount.apps.api.tests.factories.user import UserFactory
from pount.apps.public.tests.factories import ItemFactory, ProjectFactory, SetFactory, TemplateFactory

User = get_user_model()


class SetUpMixin:
    @patch("pount.apps.api.models.template.handle_update_item_metadata_on_template_save")
    def setUp(self, update_mock) -> None:
        init.initialize_roles()
        init.initialize_templates()
        self.manager = UserFactory(username="manager")
        self.member = UserFactory(username="member")
        self.public_project = ProjectFactory(
            name="Public project",
            description="Description",
        )
        self.public_project.add_member(self.member)
        self.public_project.add_member(self.manager)
        self.public_project.add_manager(self.manager)

        self.private_project = ProjectFactory(
            name="Private project",
            description="Description",
            is_public=False,
        )

        self.public_set1 = SetFactory(
            title="Public set 1",
            description="Description",
            creator=self.manager,
            template=TemplateFactory(),
            project=self.public_project,
        )
        self.public_set2 = SetFactory(
            title="Public set 2",
            description="Description",
            creator=self.manager,
            template=TemplateFactory(),
            project=self.public_project,
        )
        self.private_set = SetFactory(
            title="Private set",
            description="Description",
            is_public=False,
            creator=self.manager,
            template=TemplateFactory(),
            project=self.public_project,
        )
        self.deleted_set = SetFactory(
            title="Deleted set",
            description="Description",
            creator=self.manager,
            template=TemplateFactory(),
            project=self.public_project,
            is_deleted=True,
            deleted_at=timezone.now(),
        )

        self.public_set_of_private_project = SetFactory(
            title="Public set of private project",
            description="Description",
            creator=self.manager,
            template=TemplateFactory(),
            project=self.private_project,
        )

        self.items = []
        for i in range(5):
            ItemFactory(
                title=f"Private item {i}",
                creator=self.manager,
                is_public=False,
                set=self.private_set,
            )
            item = ItemFactory(
                title=f"Public item {i}",
                creator=self.manager,
                set=self.public_set1,
            )
            self.items.append(item)
        self.public_item_of_private_set = ItemFactory(
            title="Public item of private set",
            creator=self.manager,
            set=self.private_set,
        )
        self.public_item_of_public_set_of_private_project = ItemFactory(
            title="Public item of public set of private project",
            creator=self.manager,
            set=self.public_set_of_private_project,
        )
        self.deleted_item = ItemFactory(
            title="Deleted item",
            creator=self.manager,
            set=self.public_set1,
            is_deleted=True,
            deleted_at=timezone.now(),
        )

        self.mediafile = MediaFile.objects.create(
            filename="pount.jpg",
            component="Image",
            item=self.items[0],
            info={
                "content_type": "image/png",
                "size": 1024,
                "public_url": {
                    "url": "http://media.pount.org/pount.png",
                    "expires": dt.datetime.now().timestamp() + 3600,
                },
            },
        )
