from unittest.mock import patch

from rest_framework.reverse import reverse

from pount.tests import APITestCase


class SearchViewTest(APITestCase):
    def test_view_is_not_authenticated(self):
        with patch("pount.apps.public.views.Query"):
            response = self.get(
                reverse("public:search"),
                user=None,
            )
        self.response_ok(response)

    def test_no_user_is_passed_to_query_class(self):
        with patch("pount.apps.public.views.Query") as mock_query:
            self.get(
                reverse("public:search"),
                {
                    "page": 3,
                    "page_size": 20,
                    "project_ids": "1,2,3",
                    "set_ids": "1,2,3",
                    "q": "search me",
                },
                user=None,
                HTTP_ACCEPT_LANGUAGE="fr-FR",
            )
        mock_query.assert_called_once_with(
            language="fr",
            user=None,
            page="3",
            page_size="20",
            project_ids="1,2,3",
            set_ids="1,2,3",
        )

    def test_page_number_can_not_be_gt_100(self):
        response = self.get(
            f"{reverse('public:search')}?page=101",
        )
        self.response_bad_request(response)
