from elasticsearch_dsl import CustomField, analyzer, token_filter

THUMBNAIL_EXPIRATION = 60 * 60 * 24 * 365 * 10


class IcuCollationKeyword(CustomField):
    builtin_type = "icu_collation_keyword"
    name = "sort_keyword"


french_elision = token_filter(
    "pount_french_elision",
    type="elision",
    articles_case=True,
    articles=[
        "l",
        "m",
        "t",
        "qu",
        "n",
        "s",
        "j",
        "d",
        "c",
        "jusqu",
        "quoiqu",
        "lorsqu",
        "puisqu",
    ],
)

french_stop = token_filter(
    "french_stops",
    type="stop",
    stopwords="_french_",
)

pount_french_stemmer = token_filter(
    "pount_french_stemmer",
    type="stemmer",
    language="light_french",
)

pount_standard = analyzer(
    "pount_standard",
    char_filter=["html_strip"],
    tokenizer="icu_tokenizer",
    filter=["icu_normalizer"],
)

pount_french = analyzer(
    "pount_french",
    char_filter=["html_strip"],
    tokenizer="icu_tokenizer",
    filter=[
        french_stop,
        french_elision,
        "icu_folding",
        pount_french_stemmer,
    ],
)
