import json
from typing import Any

from django.conf import settings
from django.db import models
from django.utils.translation import gettext_lazy as _
from elasticsearch_dsl import Index

from pount.apps.api.models import Set


class MappingTypes(models.TextChoices):
    STRINGS_FR = "strings_fr", _("French text")
    STRINGS = "strings", _("Standard text")
    STRINGS_KW = "strings_kw", _("Binary text")
    DATES = "dates", _("Date and time")
    BOOLS = "bools", _("Boolean")
    LONGS = "longs", _("Integer numbers")
    FLOATS = "floats", _("Floating point numbers")


def get_settings_and_mappings(definition_file_name) -> dict:
    filename = settings.BASE_DIR / "apps/search/settings/elasticsearch" / definition_file_name
    with open(filename) as f:
        definition = json.load(f)
    return definition


def create_index(index_name: str, settings_and_mappings: dict, delete_if_exists: bool = False) -> None:
    index = Index(index_name)
    if index.exists():
        if delete_if_exists:
            index.delete()
        else:
            return
    index.create(body=settings_and_mappings)


def create_projects_index(delete_if_exists: bool = False) -> None:
    settings_and_mappings = get_settings_and_mappings("projects-index-settings.json")
    create_index(index_name="projects", settings_and_mappings=settings_and_mappings, delete_if_exists=delete_if_exists)


def create_sets_index(delete_if_exists: bool = False) -> None:
    settings_and_mappings = get_settings_and_mappings("sets-index-settings.json")
    create_index(index_name="sets", settings_and_mappings=settings_and_mappings, delete_if_exists=delete_if_exists)


def delete_items_index(set_model: Set) -> dict[str, Any]:
    return delete_index(f"items-{set_model.id.hex}")


def delete_index(name: str) -> dict[str, Any]:
    index = Index(name)
    if index.exists():
        return index.delete()
    return {"acknowledged": True}
