from unittest.mock import patch

from pount.apps.api.models.init import initialize_roles
from pount.apps.api.tests.factories.set import SetFactory
from pount.apps.search.signals import (
    delete_search_index_when_a_set_is_deleted,
    manage_search_index_when_a_set_is_created_or_updated,
)
from pount.tests import TestCase


class CreateSetSignalTest(TestCase):
    def setUp(self) -> None:
        self.patcher1 = patch("pount.apps.api.models.template.handle_update_item_metadata_on_template_save")
        self.patcher1.start()
        initialize_roles()

    def tearDown(self) -> None:
        self.patcher1.stop()

    def test_when_set_is_created_items_index_creation_task_is_called(self):
        with patch("pount.apps.search.signals.search_tasks") as search_tasks:
            set_model = SetFactory()
            manage_search_index_when_a_set_is_created_or_updated("sender", set_model, created=True)
        search_tasks.create_items_index.delay.assert_called_once_with(set_model.id)

    def test_when_set_is_soft_deleted_items_index_delete_task_is_called(self):
        with patch("pount.apps.search.signals.search_tasks") as search_tasks:
            set_model = SetFactory()
            set_model.delete()
            manage_search_index_when_a_set_is_created_or_updated("sender", set_model, created=False)
        search_tasks.delete_items_index.delay.assert_called_once_with(set_model.items_index_name)

    def test_when_set_is_deleted_index_delete_task_is_called(self):
        with patch("pount.apps.search.signals.search_tasks") as search_tasks:
            set_model = SetFactory()
            delete_search_index_when_a_set_is_deleted("sender", set_model)
        search_tasks.delete_items_index.delay.assert_called_once_with(set_model.items_index_name)
