from unittest.mock import patch
from uuid import uuid4

from pount.apps.api.models import Set
from pount.apps.api.models.init import initialize_roles
from pount.apps.api.tests.factories.set import SetFactory
from pount.apps.search.elasticsearch.index import get_settings_and_mappings
from pount.apps.search.tasks import create_items_index, delete_items_index
from pount.tests import TestCase


class CreateItemsIndexTest(TestCase):
    def setUp(self) -> None:
        self.patcher1 = patch("pount.apps.api.models.template.handle_update_item_metadata_on_template_save")
        self.patcher1.start()
        initialize_roles()
        self.set_model = SetFactory()
        self.settings = get_settings_and_mappings("items-index-settings.json")

    def tearDown(self) -> None:
        self.patcher1.stop()

    def test_create_index_is_called(self):
        with patch("pount.apps.search.tasks.create_index") as create_index:
            create_items_index(self.set_model.id)
        create_index.assert_called_once_with(f"items-{str(self.set_model.id.hex)}", self.settings)

    def test_create_index_is_not_called_if_set_does_not_exist(self):
        with patch("pount.apps.search.tasks.create_index") as create_index:
            create_items_index(uuid4().hex)
        create_index.assert_not_called()


class DeleteItemsIndexTaskTest(TestCase):
    def test_delete_index_is_called(self):
        set_id = uuid4()
        set_model = Set(id=set_id)
        index_name = set_model.items_index_name
        with patch("pount.apps.search.tasks.delete_index") as delete_index:
            delete_items_index(index_name)
        delete_index.assert_called_once_with(index_name)
