from os import environ
from pathlib import Path

from icecream import install as icecream_install

from .common import *  # noqa: F401,F403
from .common import LOGGING, SITE_NAME

DEBUG = True

# localhost alias (in /etc/hosts) to use cas6 service
ALLOWED_HOSTS = ["pount-local.unistra.fr", "localhost", ".unistra.fr"]

INTERNAL_IPS = [
    "127.0.0.1",
]
INSTALLED_APPS += [  # noqa: F405
    "debug_toolbar",
    "django_extensions",
]
DEBUG_TOOLBAR_PANELS = [
    "debug_toolbar.panels.versions.VersionsPanel",
    "debug_toolbar.panels.timer.TimerPanel",
    "debug_toolbar.panels.settings.SettingsPanel",
    "debug_toolbar.panels.headers.HeadersPanel",
    "debug_toolbar.panels.request.RequestPanel",
    "debug_toolbar.panels.sql.SQLPanel",
    "debug_toolbar.panels.staticfiles.StaticFilesPanel",
    "debug_toolbar.panels.templates.TemplatesPanel",
    "debug_toolbar.panels.cache.CachePanel",
    "debug_toolbar.panels.signals.SignalsPanel",
    "debug_toolbar.panels.logging.LoggingPanel",
    "debug_toolbar.panels.redirects.RedirectsPanel",
    "debug_toolbar.panels.profiling.ProfilingPanel",
]

MIDDLEWARE += [  # noqa: F405
    "debug_toolbar.middleware.DebugToolbarMiddleware",
]

EMAIL_HOST = "localhost"
EMAIL_PORT = 1025
EMAIL_HOST_USER = ""
EMAIL_HOST_PASSWORD = ""
EMAIL_USE_TLS = False
DEFAULT_FROM_EMAIL = "admin@pount.org"

CAS_SERVER_URL = "https://cas-dev.unistra.fr/cas/"

#####################
# Log configuration #
#####################

LOGGING["handlers"]["file"]["filename"] = environ.get(
    "LOG_DIR", Path("/tmp").resolve(strict=True) / f"{SITE_NAME}.log"
)
LOGGING["handlers"]["file"]["level"] = "DEBUG"
LOGGING["handlers"]["cron"]["filename"] = Path("/tmp").resolve(strict=True) / f"{SITE_NAME}_cron.log"

for logger in LOGGING["loggers"]:
    LOGGING["loggers"][logger]["level"] = "DEBUG"


##############
# S3 STORAGE #
##############
AWS_STORAGE_BUCKET_NAME = environ.get("AWS_STORAGE_BUCKET_NAME", None)


REST_FRAMEWORK["DEFAULT_AUTHENTICATION_CLASSES"] = [
    "rest_framework_simplejwt.authentication.JWTAuthentication",
    "rest_framework.authentication.TokenAuthentication",
    "rest_framework.authentication.SessionAuthentication",
]


icecream_install()
