# flake8: noqa:E501
import sentry_sdk
from sentry_sdk.integrations.celery import CeleryIntegration
from sentry_sdk.integrations.django import DjangoIntegration
from sentry_sdk.integrations.redis import RedisIntegration

from .common import *
from .common import DATABASES, LOGGING

#######################
# Debug configuration #
#######################

DEBUG = True


#####################
# CAS configuration #
#####################
CAS_FORCE_SSL_SERVICE_URL = True
CAS_SERVER_URL = "https://cas-dev.unistra.fr/cas/"


##########################
# Database configuration #
##########################

DATABASES["default"]["NAME"] = "{{ default_db_name }}"
DATABASES["default"]["HOST"] = "{{ default_db_host }}"
DATABASES["default"]["USER"] = "{{ default_db_user }}"
DATABASES["default"]["PASSWORD"] = "{{ default_db_password }}"


############################
# Allowed hosts & Security #
############################

ALLOWED_HOSTS = [
    ".u-strasbg.fr",
    ".unistra.fr",
]

SECURE_PROXY_SSL_HEADER = ("HTTP_X_FORWARDED_PROTOCOL", "ssl")

#####################
# Log configuration #
#####################

LOGGING["handlers"]["file"]["filename"] = "{{ remote_current_path }}/log/app.log"  # noqa: E501
LOGGING["handlers"]["cron"]["filename"] = "{{ remote_current_path }}/log/cron.log"  # noqa: E501

for logger in LOGGING["loggers"]:
    LOGGING["loggers"][logger]["level"] = "DEBUG"

##############
# S3 STORAGE #
##############
AWS_ACCESS_KEY_ID = "{{ aws_access_key_id }}"
AWS_SECRET_ACCESS_KEY = "{{ aws_secret_access_key }}"
AWS_STORAGE_BUCKET_NAME = "pount-test"

##########
# CACHES #
##########
CACHES["default"]["LOCATION"] = "redis://django-redis-test.di.unistra.fr:6379/7"

##########
# Sentry #
##########
sentry_sdk.init(
    dsn=SENTRY_DSN,
    integrations=[DjangoIntegration(), CeleryIntegration(), RedisIntegration()],
    environment="test",
    traces_sample_rate=1.0,
    release="{{ release_name }}",
    send_default_pii=True,
)


#################
# ELASTICSEARCH #
#################
ELASTICSEARCH_DSL["default"]["hosts"] = "{{ elasticsearch_host }}"


##########
# CELERY #
##########
RABBITMQ_USER = "{{ rabbitmq_user }}"
RABBITMQ_PASSWORD = "{{ rabbitmq_password }}"
RABBITMQ_SERVER = "{{ rabbitmq_server }}"
RABBITMQ_VHOST = "{{ rabbitmq_vhost }}"
CELERY_NAME = "pount_test"
CELERY_BROKER_URL = f"amqp://{RABBITMQ_USER}:{RABBITMQ_PASSWORD}@{RABBITMQ_SERVER}/{RABBITMQ_VHOST}"
BROKER_URL = CELERY_BROKER_URL  # health_check.contrib.rabbitmq.backends.RabbitMQHealthCheck uses this :-(
CELERY_RESULT_BACKEND = ""


###########
# CAMELOT #
###########
CAMELOT["TOKEN"] = "{{ camelot_token }}"
CAMELOT["URL"] = "https://camelotv3-test.app.unistra.fr/"


###########
# MONGODB #
###########
MONGODB_USER = "{{ mongodb_user }}"
MONGODB_PASSWORD = "{{ mongodb_password }}"
MONGODB_HOST = "{{ mongodb_host }}"
MONGODB_DATABASE = "{{ mongodb_database }}"
MONGODB_URI = f"mongodb://{MONGODB_USER}:{MONGODB_PASSWORD}@{MONGODB_HOST}/?retryWrites=true&w=majority&authSource={MONGODB_DATABASE}"

#######
# DRF #
#######
REST_FRAMEWORK["DEFAULT_AUTHENTICATION_CLASSES"] = [
    "rest_framework_simplejwt.authentication.JWTAuthentication",
    "rest_framework.authentication.TokenAuthentication",
    "rest_framework.authentication.SessionAuthentication",
]
