from os import environ
from pathlib import Path

from .common import *  # noqa: F401,F403
from .common import DATABASES, LOGGING, SITE_NAME

DEBUG = True
LANGUAGE_CODE = "en-US"

DATABASES["default"]["HOST"] = environ.get("DEFAULT_DB_HOST", "localhost")
DATABASES["default"]["NAME"] = environ.get("DEFAULT_DB_NAME", "pount")
DATABASES["default"]["USER"] = environ.get("DEFAULT_DB_USER", "pount")
DATABASES["default"]["PASSWORD"] = environ.get("DEFAULT_DB_PASSWORD", "pount")


ALLOWED_HOSTS = ["*"]

#####################
# Log configuration #
#####################

LOGGING["handlers"]["file"]["filename"] = environ.get(
    "LOG_DIR", Path("/tmp").resolve(strict=True) / f"test_{SITE_NAME}.log"
)

LOGGING["handlers"]["file"]["level"] = "DEBUG"
LOGGING["handlers"]["cron"]["filename"] = (
    Path("/tmp").resolve(strict=True) / f"test_{SITE_NAME}_cron.log"
)

for logger in LOGGING["loggers"]:
    LOGGING["loggers"][logger]["level"] = "DEBUG"

TEST_RUNNER = "django.test.runner.DiscoverRunner"

##############
# S3 STORAGE #
##############
AWS_STORAGE_BUCKET_NAME = environ.get(
    "AWS_STORAGE_BUCKET_NAME", "pount-unittest"
)

##########
# CACHES #
##########
CACHES = {
    "default": {
        "BACKEND": "django.core.cache.backends.dummy.DummyCache",
    }
}

#################
# ELASTICSEARCH #
#################
ELASTICSEARCH_SIGNAL_PROCESSOR = "pount.apps.search.signals.DummySignalProcessor"


#######
# DRF #
#######
REST_FRAMEWORK["DEFAULT_AUTHENTICATION_CLASSES"] = [
    "rest_framework_simplejwt.authentication.JWTAuthentication",
    "rest_framework.authentication.TokenAuthentication",
    "rest_framework.authentication.SessionAuthentication",
]

###########
# CAMELOT #
###########
CAMELOT = {
    "TOKEN": "0552fd8d-0b37-46c6-b462-ff43f6a94ba9",
    "URL": "https://camelot.unistra.fr/",
}
