from django.conf import settings
from django.contrib import admin
from django.urls import include, path
from drf_spectacular.views import SpectacularAPIView, SpectacularSwaggerView

from .views import HealthCheckView

admin.autodiscover()

urlpatterns = [
    path("p/", include("pount.apps.public.urls")),
    path("api/", include("pount.apps.api.urls")),
    path("api/schema/", SpectacularAPIView.as_view(), name="schema"),
    path("api/doc/", SpectacularSwaggerView.as_view(url_name="schema"), name="swagger-ui"),
    path("cas/", include("django_cas.urls")),
    path("admin/", admin.site.urls),
    path("_hc/", HealthCheckView.as_view()),
]

if settings.DEBUG and "debug_toolbar" in settings.INSTALLED_APPS:
    import debug_toolbar

    urlpatterns += [path("__debug__/", include(debug_toolbar.urls))]
